/*
 * Copyright (c) 2002-2008 Gargoyle Software Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.gargoylesoftware.htmlunit.javascript.host;

import com.gargoylesoftware.htmlunit.html.HtmlFrameSet;

/**
 * Wrapper for the HTML element "frameset".
 *
 * @version $Revision: 3026 $
 * @author Bruce Chapman
 */
public class HTMLFrameSetElement extends HTMLElement {

    private static final long serialVersionUID = 5630843390548382869L;

    /**
     * Creates a new frameset instance.
     */
    public HTMLFrameSetElement() {
        // Empty.
    }

    /**
     * Sets the rows property.
     *
     * @param rows the rows attribute value
     */
    public void jsxSet_rows(final String rows) {
        final HtmlFrameSet htmlFrameSet = (HtmlFrameSet) getHtmlElementOrNull();
        if (htmlFrameSet != null) {
            htmlFrameSet.setAttributeValue("rows", rows);
        }
    }

    /**
     * Gets the rows property.
     *
     * @return the rows attribute value
     */

    public String jsxGet_rows() {
        final HtmlFrameSet htmlFrameSet = (HtmlFrameSet) getHtmlElementOrNull();
        return htmlFrameSet.getRowsAttribute();
    }

    /**
     * Sets the cols property.
     *
     * @param cols the cols attribute value
     */
    public void jsxSet_cols(final String cols) {
        final HtmlFrameSet htmlFrameSet = (HtmlFrameSet) getHtmlElementOrNull();
        if (htmlFrameSet != null) {
            htmlFrameSet.setAttributeValue("cols", cols);
        }
    }

    /**
     * Gets the cols property.
     *
     * @return the cols attribute value
     */
    public String jsxGet_cols() {
        final HtmlFrameSet htmlFrameSet = (HtmlFrameSet) getHtmlElementOrNull();
        return htmlFrameSet.getColsAttribute();
    }

}
